@@ -7,11 +7,11 @@
 import sys
 import threading
 
-from thrift.transport import TSocket
-from thrift.transport import TTransport
-from thrift.protocol import TBinaryProtocol
+from nebula.fbthrift.transport import TSocket
+from nebula.fbthrift.transport import TTransport
+from nebula.fbthrift.protocol import TBinaryProtocol
 
-from graph import GraphService
+from nebula.graph import GraphService
 
 
 class ConnectionPool(object):
@@ -72,7 +72,7 @@ class ConnectionPool(object):
             return None
 
     def return_connection(self, conn):
-        """ return a thrift connection to the pool.
+        """ return a fbthrift connection to the pool.
         Returns: None
         """
         if self._closed:
